library(tidyverse)
library(lfe)
library(stargazer)
library(starpolishr)
library(AER)
library(ivpack)
library(stringr)
library(rlang)
library(ggsignif)
library(WeightIt)
library(radiant.data)
library(ri2)
library(haven)
library(xtable)


select = dplyr::select
set.seed(9876)



prepare_data = function() {
  data = readstata13::read.dta13('data/raw/wave201806_deidentified_minimal.dta', generate.factors = T) %>% 
    filter(!is.na(participate_july1_2017), !is.na(gender), !is.na(birth_year), !is.na(monthly_income_total), !is.na(expectedincome_age40), !is.na(realest_totalowned)) %>%  
    rename(plan_july1_2018_positive = plan_july1st_2018_positive,
           plan_july1_2018 = plan_july1st_2018,
           participate_july1_2018 = participate_july1st_2018) %>%
    mutate(age2017 = 2017-birth_year, 
           approximate_treatment_cell_tier = treatment_cell_tier/100,
           treatment = replace_na(treatment, 0)) %>%
    group_by(treatment_cell) %>%
    mutate(treatment_cell_tier = sum(treatment_main)/n(),
           approximate_treatment_cell_tier = factor(approximate_treatment_cell_tier, levels = c(0, 0.01, 0.5, 0.75))) %>%
    ungroup()
  data$weight=1
  
  data$past_protests = data %>% select(participate_anti_curriculum, participate_antimainland_moms, participate_july1_2014, participate_july1_2015, participate_july1_2016, participate_umbrella, participate_oc_referendum) %>% rowSums(na.rm=T) > 0
  
  model = lm(plan_july1_2017_pos ~ gender + age2017 + monthly_income_total + expectedincome_age40 + realest_totalowned + past_protests, data=data, weights=data$weight)

  data$predicted_protest_participation = predict(model, data)
  if (merge_cells) {
    data = data %>% group_by(treatment_cell) %>% mutate(cell_size = n()) %>% ungroup()
    data$treatment_cell2 = dplyr::recode(data$approximate_treatment_cell_tier, `0` = '0.00 treated merge', `0.01` = '0.01 treated merge', `0.5` = '0.5 treated merge', `0.75` = '0.75 treated merge')
    data$treatment_cell[data$cell_size<=5] = data$treatment_cell2[data$cell_size<=5]
  }
  data$treatment_cell = as.factor(data$treatment_cell)
  return(data)
}

formatP = function(x, p=FALSE, latex=FALSE) {
  value = format(round(x, digits=3), nsmall=3)
  value = formatC(value, digits=3)
  if (p & x<0.001) {
    val = str_interp('p<0.001')
  } else if (p & x>=0.001) {
    val = str_interp('p=${value}')
  } else if (!p & x<0.001) {
    val = str_interp('<0.001')
  } else {
    val = str_interp('${value}')
  }
  if (latex) {
    val = str_replace(val, '<', '$\\leq$')
  }
  val
}

formatted_mean = function(x) {
  mean(x, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
}
formatted_sd = function(x) {
  sd(x, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
}

formatted_mean_weighted = function(x, w) {
  weighted.mean(x, w, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
}



# ggplot themes
palette_two = c('#F8766D', '#00BFC4')
palette_two_placebo_treatment = c('#00BA38', '#00BFC4')
palette_three = c('#F8766D', '#00BA38', '#00BFC4')

theme_two = list(theme_bw(base_size=11),
                 theme(axis.text = element_text(size=rel(2), color='black'),
                       axis.title = element_text(size=rel(2.2)),
                       strip.text = element_text(size=14)),
                 scale_fill_manual(values=palette_two),
                 scale_color_manual(values=palette_two))

theme_two_placebo_treatment = list(theme_bw(base_size=11),
                              theme(axis.text = element_text(size=rel(2), color='black'),
                                    axis.title = element_text(size=rel(2.2)),
                                    strip.text = element_text(size=14)),
                              scale_fill_manual(values=palette_two_placebo_treatment),
                              scale_color_manual(values=palette_two_placebo_treatment))

theme_three = list(theme_bw(base_size=11),
                   theme(axis.text = element_text(size=rel(2), color='black'),
                         axis.title = element_text(size=rel(2.2)),
                         strip.text = element_text(size=14)),
                   scale_fill_manual(values=palette_three),
                   scale_color_manual(values=palette_three))
